:orphan:

=========
Tutorials
=========

New to *pydicom*? Then these tutorials should get you up and running.

.. toctree::
   :maxdepth: 1

   installation
   virtualenvs
   dataset_basics
   pixel_data/compressing
   waveforms
   filesets
   sr_basics
   dicom_json
   contributing_code
   contributing_docs
